@@ -40,6 +40,7 @@ from .constants import (
     FileTransferType,
     QueryStatus,
 )
+from .description import CLIENT_NAME
 from .errorcode import (
     ER_CURSOR_IS_CLOSED,
     ER_FAILED_PROCESSING_PYFORMAT,
@@ -247,6 +248,7 @@ class SnowflakeCursor:
         self._result_set: Optional["ResultSet"] = None
         self._result_state: ResultState = ResultState.DEFAULT
         self._use_dict_result = use_dict_result
+        self.query: Optional[str] = None
         # TODO: self._query_result_format could be defined as an enum
         self._query_result_format: Optional[str] = None
 
@@ -551,6 +553,7 @@ class SnowflakeCursor:
                 {p["name"]: p["value"] for p in parameters}
             )
 
+        self.query = query
         self._sequence_counter = -1
         return ret
 
@@ -645,13 +648,27 @@ class SnowflakeCursor:
                 processed_params = self._connection._process_params_pyformat(
                     params, self
                 )
+                # SNOW-513061 collect telemetry for empty sequence usage before we make the breaking change announcement
+                if params is not None and len(params) == 0:
+                    self._log_telemetry_job_data(
+                        TelemetryField.EMPTY_SEQ_INTERPOLATION,
+                        TelemetryData.TRUE
+                        if self.connection._interpolate_empty_sequences
+                        else TelemetryData.FALSE,
+                    )
                 if logger.getEffectiveLevel() <= logging.DEBUG:
                     logger.debug(
                         f"binding: [{self._format_query_for_log(command)}] "
                         f"with input=[{params}], "
                         f"processed=[{processed_params}]",
                     )
-                if len(processed_params) > 0:
+                if (
+                    self.connection._interpolate_empty_sequences
+                    and processed_params is not None
+                ) or (
+                    not self.connection._interpolate_empty_sequences
+                    and len(processed_params) > 0
+                ):
                     query = command % processed_params
                 else:
                     query = command
@@ -1196,10 +1213,13 @@ class SnowflakeCursor:
             with self._lock_canceling:
                 self._connection._cancel_query(query, self._request_id)
 
-    def _log_telemetry_job_data(self, telemetry_field, value):
+    def _log_telemetry_job_data(
+        self, telemetry_field: TelemetryField, value: Any
+    ) -> None:
         """Builds an instance of TelemetryData with the given field and logs it."""
         obj = {
-            "type": telemetry_field,
+            "type": telemetry_field.value,
+            "source": self._connection.application if self._connection else CLIENT_NAME,
             "query_id": self._sfqid,
             "value": int(value),
         }
