@@ -172,27 +172,22 @@ def _update_progress(
         status = "Halt...\r\n"
     if progress >= 1:
         progress = 1
-        status = "Done ({elapsed_time:.3f}s, {throughput:.2f}MB/s).\r\n".format(
-            elapsed_time=elapsed_time, throughput=throughput
-        )
+        status = f"Done ({elapsed_time:.3f}s, {throughput:.2f}MB/s).\r\n"
     if not status and show_progress_bar:
-        status = "({elapsed_time:.3f}s, {throughput:.2f}MB/s)".format(
-            elapsed_time=elapsed_time, throughput=throughput
-        )
+        status = f"({elapsed_time:.3f}s, {throughput:.2f}MB/s)"
     if status:
         block = int(round(bar_length * progress))
-        text = "\r{file_name}({size:.2f}MB): [{bar}] {percentage:.2f}% {status}".format(
-            file_name=file_name,
-            size=total_size,
-            bar="#" * block + "-" * (bar_length - block),
-            percentage=progress * 100.0,
-            status=status,
+
+        text = (
+            f"\r{file_name}({total_size:.2f}MB): "
+            f"[{'#' * block + '-' * (bar_length - block)}] "
+            f"{progress * 100.0:.2f}% {status}"
         )
         output_stream.write(text)
         output_stream.flush()
     logger.debug(
-        f"filename: {file_name}, start_time: {start_time}, total_size: {total_size}, progress: {progress}, "
-        f"show_progress_bar: {show_progress_bar}"
+        f"filename: {file_name}, start_time: {start_time}, total_size: {total_size}, "
+        f"progress: {progress}, show_progress_bar: {show_progress_bar}"
     )
     return progress == 1.0
 
@@ -300,7 +295,7 @@ class StorageCredential:
         self.timestamp = time()
         self.lock = threading.Lock()
         self.connection = connection
-        self.command = command
+        self._command = command
 
     def update(self, cur_timestamp):
         with self.lock:
@@ -309,7 +304,7 @@ class StorageCredential:
             logger.debug("Renewing expired storage token.")
             ret = self.connection.cursor()._execute_helper(self._command)
             self.creds = ret["data"]["stageInfo"]["creds"]
-            self.timestamp = time.time()
+            self.timestamp = time()
 
 
 @dataclass
@@ -402,6 +397,17 @@ class SnowflakeFileTransferAgent:
                 m.multipart_threshold = self._multipart_threshold
 
         logger.debug(f"parallel=[{self._parallel}]")
+        if self._raise_put_get_error and not self._file_metadata:
+            Error.errorhandler_wrapper(
+                self._cursor.connection,
+                self._cursor,
+                OperationalError,
+                {
+                    "msg": "While getting file(s) there was an error: "
+                    "the file does not exist.",
+                    "errno": ER_FILE_NOT_EXISTS,
+                },
+            )
         self.transfer(self._file_metadata)
 
         # turn enum to string, in order to have backward compatible interface
@@ -579,7 +585,7 @@ class SnowflakeFileTransferAgent:
                 result = (False, e)
             try:
                 _callback(*result, file_meta)
-            except Exception as e:  # NOQA
+            except Exception as e:
                 # TODO: if an exception happens in a callback, the exception will not
                 #  propagate to the main thread. We need to save these Exceptions
                 #  somewhere and then re-raise by the main thread. For now let's log
@@ -666,7 +672,7 @@ class SnowflakeFileTransferAgent:
         raise Exception(f"{self._stage_location_type} is an unknown stage type")
 
     def _transfer_accelerate_config(self) -> None:
-        if self._stage_location_type == S3_FS:
+        if self._stage_location_type == S3_FS and self._file_metadata:
             client = self._create_file_transfer_client(self._file_metadata[0])
             self._use_accelerate_endpoint = client.transfer_accelerate_config()
 
@@ -705,12 +711,9 @@ class SnowflakeFileTransferAgent:
                     )
 
                     logger.debug(
-                        "raise_put_get_error: %s, %s, %s, %s, %s",
-                        self._raise_put_get_error,
-                        meta.result_status,
-                        type(meta.result_status),
-                        ResultStatus.ERROR,
-                        type(ResultStatus.ERROR),
+                        f"raise_put_get_error: {self._raise_put_get_error}, "
+                        f"{meta.result_status}, {type(meta.result_status)}, "
+                        f"{ResultStatus.ERROR}, {type(ResultStatus.ERROR)}",
                     )
                     if self._raise_put_get_error and error_details:
                         Error.errorhandler_wrapper(
@@ -718,7 +721,10 @@ class SnowflakeFileTransferAgent:
                             self._cursor,
                             OperationalError,
                             {
-                                "msg": error_details,
+                                "msg": "While putting file(s) there was an error: "
+                                f"'{error_details}', this might be caused by "
+                                f"your access to the blob storage provider, "
+                                f"or by Snowflake.",
                                 "errno": ER_FAILED_TO_UPLOAD_TO_STAGE,
                             },
                         )
@@ -768,7 +774,10 @@ class SnowflakeFileTransferAgent:
                             self._cursor,
                             OperationalError,
                             {
-                                "msg": error_details,
+                                "msg": "While getting file(s) there was an error: "
+                                f"'{error_details}', this might be caused by "
+                                f"your access to the blob storage provider, "
+                                f"or by Snowflake.",
                                 "errno": ER_FAILED_TO_DOWNLOAD_FROM_STAGE,
                             },
                         )
@@ -939,9 +948,7 @@ class SnowflakeFileTransferAgent:
                     self._cursor,
                     ProgrammingError,
                     {
-                        "msg": "The local path is not a directory: {}".format(
-                            self._local_location
-                        ),
+                        "msg": f"The local path is not a directory: {self._local_location}",
                         "errno": ER_LOCAL_PATH_NOT_DIRECTORY,
                     },
                 )
@@ -1095,11 +1102,11 @@ class SnowflakeFileTransferAgent:
 
                 if encoding is not None:
                     logger.debug(
-                        "detected the encoding %s: file=%s", encoding, file_name
+                        f"detected the encoding {encoding}: file={file_name}",
                     )
                     current_file_compression_type = lookup_by_mime_sub_type(encoding)
                 else:
-                    logger.debug("no file encoding was detected: file=%s", file_name)
+                    logger.debug(f"no file encoding was detected: file={file_name}")
 
                 if (
                     current_file_compression_type is not None
