@@ -5,6 +5,7 @@
 #
 
 import logging
+from enum import Enum, unique
 from threading import Lock
 
 from .secret_detector import SecretDetector
@@ -13,7 +14,8 @@ from .test_util import ENABLE_TELEMETRY_LOG, rt_plain_logger
 logger = logging.getLogger(__name__)
 
 
-class TelemetryField(object):
+@unique
+class TelemetryField(Enum):
     # Fields which can be logged to telemetry
     TIME_CONSUME_FIRST_RESULT = "client_time_consume_first_result"
     TIME_CONSUME_LAST_RESULT = "client_time_consume_last_result"
@@ -21,6 +23,7 @@ class TelemetryField(object):
     TIME_PARSING_CHUNKS = "client_time_parsing_chunks"
     SQL_EXCEPTION = "client_sql_exception"
     GET_PARTITIONS_USED = "client_get_partitions_used"
+    EMPTY_SEQ_INTERPOLATION = "client_pyformat_empty_seq_interpolation"
     # fetch_pandas_* usage
     PANDAS_FETCH_ALL = "client_fetch_pandas_all"
     PANDAS_FETCH_BATCHES = "client_fetch_pandas_batches"
@@ -29,13 +32,13 @@ class TelemetryField(object):
     ARROW_FETCH_BATCHES = "client_fetch_arrow_batches"
     # Keys for telemetry data sent through either in-band or out-of-band telemetry
     KEY_TYPE = "type"
+    KEY_SOURCE = "source"
     KEY_SFQID = "QueryID"
     KEY_SQLSTATE = "SQLState"
     KEY_DRIVER_TYPE = "DriverType"
     KEY_DRIVER_VERSION = "DriverVersion"
     KEY_REASON = "reason"
     KEY_ERROR_NUMBER = "ErrorNumber"
-    KEY_ERROR_MESSAGE = "ErrorMessage"
     KEY_STACKTRACE = "Stacktrace"
     KEY_EXCEPTION = "Exception"
 
